package caterpillar;

import java.awt.*;
import java.awt.geom.*;

import visual.statik.described.*;

/**
 * The abstract parent of all Caterpillar classes.
 * 
 * @author Prof. David Bernstein, James Madison University
 * @version 1.0
 */
public abstract class Caterpillar extends AggregateContent
{
  private BasicStroke thick;
  private Color lightGreen, darkGreen, red;

  /**
   * Default Constructor.
   */
  protected Caterpillar()
  {
    super();

    thick = new BasicStroke(2.0f);
    darkGreen = new Color(0, 128, 0);
    lightGreen = new Color(0, 204, 0);
    red = new Color(128, 0, 0);
  }

  /**
   * Add a segment of the body at the given position.
   * 
   * @param x  The x-coordinate
   * @param y  The y-coordinate
   */
  protected void addBodyPart(final double x, final double y)
  {
    Content bodyPart = new Content(new Ellipse2D.Double(x, y, 30.0, 30.0), darkGreen, lightGreen, thick);
    Content highlight = new Content(new Ellipse2D.Double(x+5.0, y+5.0, 5.0, 5.0), Color.YELLOW, Color.YELLOW, null);
    add(bodyPart);
    add(highlight);
  }

  /**
   * Add the head at the given position.
   * 
   * @param x  The x-coordinate
   * @param y  The y-coordinate
   */
  protected void addHead(final double x, final double y)
  {
    addBodyPart(x, y);

    Content bodyPart = new Content(new Ellipse2D.Double(x, y, 30.0, 30.0), darkGreen, lightGreen, thick);
    add(bodyPart);

    Content eye = new Content(new Ellipse2D.Double(x+20.0, y+7.0, 8.0, 18.0), Color.WHITE, Color.WHITE, null);
    Content pupil = new Content(new Ellipse2D.Double(x+22.0, y+14.0, 8.0, 8.0), Color.BLACK, Color.BLACK, null);
    add(eye);
    add(pupil);

    Content mouth = new Content(new QuadCurve2D.Double(x+10.0, y+20.0, x+15, y+28, x+22.0, y+28.0), red, red, thick);
    add(mouth);

    Content antenna = new Content(new QuadCurve2D.Double(x+5.0, y-15.0, x+15.0, y-10.0, x+15.0, y), Color.BLACK, Color.BLACK, thick);
    add(antenna);
  }

}
