package caterpillar;

import java.awt.geom.*;
import visual.statik.described.*;
import visual.dynamic.described.*;

/**
 * A Caterpillar that crawls across the screen from left to right 
 * and is thrown back to the left.
 * 
 * @author Prof. David Bernstein, James Madison University
 * @version 1.0
 */
public class CrawlingCaterpillar extends DescribedSprite
{
  /**
   * Explicit Value Constructor.
   * 
   * @param xInitial The initial x-coordinate on the stage
   * @param yInitial The initial y-coordinate on the stage
   */
  public CrawlingCaterpillar(double xInitial, double yInitial)
  {
    super();
    ExpandedCaterpillar expanded = new ExpandedCaterpillar();
    CompressedCaterpillar compressed = new CompressedCaterpillar();
    CircledCaterpillar circled = new CircledCaterpillar();
    int time = 4000;
    double x = xInitial;
    for (int i=0; i<15; i++)
    {
      addKeyTime(time,     x, yInitial, 0.00, 1.0, compressed);
      addKeyTime(time+500, x, yInitial, 0.00, 1.0, expanded);
      time += 1000;
      x += 30.0;
    }
    addKeyTime(19000, x, yInitial, 0.00, 1.0, expanded);
    addKeyTime(19100, x, yInitial, -1.57, 1.0, expanded);
    addKeyTime(21100, -150.0, -60.0, -15.70, 1.0, circled);
  }

  /**
   * A convenience method that adds a key time to this DescribedSprite.
   * 
   * @param time The time
   * @param x The x-coordinate
   * @param y The y-coordinate
   * @param r The rotation angle
   * @param s The scale factor
   * @param c The Content to use (or null)
   */
  private void addKeyTime(int time, double x, double y, double r, double s, AggregateContent c)
  {
    addKeyTime(time, new Point2D.Double(x, y), Double.valueOf(r), Double.valueOf(s), c);
  }
}
