package cocoon;

import java.awt.geom.*;

import visual.statik.described.*;
import visual.dynamic.described.*;

/**
 * A Cocoon that shakes back and forth.
 * 
 * @author Prof. David Bernstein, James Madison University
 * @version 1.0
 */
public class ShakingCocoon extends DescribedSprite
{
  /**
   * Explicit Value Constructor.
   * 
   * @param xInitial The initial x-coordinate on the stage
   * @param yInitial The initial y-coordinate on the stage
   */
  public ShakingCocoon(double xInitial, double yInitial)
  {
    super();
    Cocoon middle = new Cocoon(0.0, 0.0, 0.0);
    Cocoon right = new Cocoon(0.0, 0.0, 2.0);
    Cocoon left = new Cocoon(0.0, 0.0, -1.0);
    
    for (int time=4000; time<=14000; time+=2000)
    {
      addKeyTime(    time+0, xInitial, yInitial, middle);
      addKeyTime(  time+500, xInitial, yInitial, right);
      addKeyTime( time+1000, xInitial, yInitial, middle);
      addKeyTime( time+1500, xInitial, yInitial, left);
      addKeyTime( time+2000, xInitial, yInitial, middle);
    }
  }

  
 /**
  * A convenience method that adds a key time (with a rotation of 0.0 and a scaling of 1.0)
  * to this DescribedSprite.
  * 
  * @param time The time
  * @param x The x-coordinate
  * @param y The y-coordinate
  * @param c The Content to use (or null)
  */  
  private void addKeyTime(int time, double x, double y, AggregateContent c)
  {
      addKeyTime(time, new Point2D.Double(x, y), Double.valueOf(0.0), Double.valueOf(1.0), c);
  }
}
