package firstflight;

import app.*;
import io.*;
import library.AudioSprite;

import java.awt.*;
import java.io.*;

import javax.sound.sampled.LineUnavailableException;
import javax.sound.sampled.UnsupportedAudioFileException;
import javax.swing.*;
import visual.*;
import visual.dynamic.described.*;
import visual.statik.sampled.*;


import caterpillar.*;
import cocoon.*;
import flower.*;

/**
 * The abstract parent of all Caterpillar classes.
 * 
 * @author Prof. David Bernstein, James Madison University
 * @version 1.0
 */
public class FirstFlightDemo extends JApplication
{
  private AudioSprite player;
  private Stage      stage;


  public static void main(String[] args)
  {
    JApplication demo = new FirstFlightDemo(args, 640, 480);
    invokeInEventDispatchThread(demo);
  }


  /**
   * Explicit Value Constructor.
   * 
   * @param args   The command-line arguments
   * @param width  The width of the Stage
   * @param height The height of the Stage
   */
  public FirstFlightDemo(String[] args, int width, int height)
  {
    super(args, width, height);
  }

  /**
   * The entry point
   */
  public void init()
  {
    ResourceFinder finder  = ResourceFinder.createInstance(new resources.Marker());       
    ContentFactory factory = new ContentFactory(finder);       
    
    // The Stage
    stage = new Stage(10);
    stage.setBackground(Color.WHITE);
    stage.setRestartTime(-1);
    VisualizationView stageView = stage.getView();       
    stageView.setBounds(0,0, width, height);       
    Content background = factory.createContent("background.png");
    stage.add(background);
    
    // The Sprites
    stage.add(new ShakingCocoon(170,60));
    stage.add(new CrawlingCaterpillar(  0.0, 360.0));
    stage.add(new LaunchingFlower(410, 165));

    // Sets and props
    Content foreground = factory.createContent("foreground.png", 4);
    stage.add(foreground);

    // The title 
    stage.add(new Title());
    
    // The score
    InputStream is = finder.findInputStream("FirstFlight.wav");
    try
    {
      player = new AudioSprite(is, 4000);
      stage.add(player);
    }
    catch (IOException | LineUnavailableException | UnsupportedAudioFileException e)
    {
      JOptionPane.showMessageDialog(null,  "Unable to play the audio.", 
          "Error", JOptionPane.ERROR_MESSAGE);
    }
    
    JPanel contentPane = (JPanel)getContentPane();
    contentPane.setLayout(null);
    contentPane.add(stageView);
  }

  /**
   * Start this demo.
   */
  public void start()
  {
    stage.start();
  }

  /**
   * Stop this demo.
   */
  public void stop()
  {
    stage.stop();
  }
}