package flower;

import java.awt.*;
import java.awt.geom.*;
import java.util.*;
import visual.statik.described.*;

/**
 * The abstract parent of all Flower classes.
 * 
 * @author Prof. David Bernstein, James Madison University
 * @version 1.0
 */
public abstract class Flower extends AggregateContent
{
  private ArrayList<Point2D.Double> petals;
  private BasicStroke thin, thick;
  private Color darkGreen, yellow;
  private Point2D.Double m;

  /**
   * Default Constructor.
   */
  protected Flower()
  {
    super();

    thin = new BasicStroke(1.0f);
    thick = new BasicStroke(8.0f);
    darkGreen = new Color(0, 128, 0);
    yellow = Color.yellow;

    petals = new ArrayList<Point2D.Double>();
    petals.add(new Point2D.Double(30.0, 0.0)); // 1
    petals.add(new Point2D.Double(45.0, 45.0)); // 3
    petals.add(new Point2D.Double(5.0, 30.0)); // 5
    petals.add(new Point2D.Double(50.0, 30.0)); // 2
    petals.add(new Point2D.Double(15.0, 45.0)); // 4
    petals.add(new Point2D.Double(5.0, 10.0)); // 6

    m = new Point2D.Double(30.0, 27.0);
  }

  /**
   * Add petals to the Flower.
   * 
   * @param x
   *          The x-coordinate
   * @param y
   *          The y-coordinate
   */
  protected void addPetals(double x, double y)
  {
    for (Point2D.Double p : petals)
    {
      Content petal = new Content(new Ellipse2D.Double(x + p.x, y + p.y, 30.0, 30.0), Color.BLACK,
          yellow, thin);
      add(petal);
    }
  }

  /**
   * Add the middle of the Flower.
   * 
   * @param x
   *          The x-coordinate
   * @param y
   *          The y-coordinate
   */
  protected void addMiddle(double x, double y)
  {
    Content middle = new Content(new Ellipse2D.Double(x + m.x, y + m.y, 30.0, 30.0), Color.BLACK,
        Color.BLACK, thin);
    add(middle);
  }

  /**
   * Add the stem to the Flower.
   * 
   * @param x
   *          The x-coordinate
   * @param y
   *          The y-coordinate
   * @param xLean
   *          The amount of lean to the right
   * @param yLean
   *          The amount of downward lean
   */
  protected void addStem(double x, double y, double xLean, double yLean)
  {
    Content stem = new Content(
        new Line2D.Double(x + 45.0, y + 285.0, x + xLean + 45.0, y + yLean + 45.0), darkGreen,
        darkGreen, thick);
    add(stem);
  }

  /**
   * Add the mouth to the middle of the Flower.
   * 
   * @param x
   *          The x-coordinate
   * @param y
   *          The y-coordinate
   * @param smile
   *          Whether the mouth should be smiling
   */
  protected void addMouth(double x, double y, boolean smile)
  {
    double size = 0.0;
    if (smile)
    {
      size = 20.0;
    }
    Content mouth = new Content(new Arc2D.Double(x + m.x + 5, y + m.y + 5 + (20.0 - size) / 2.0,
        20.0, size, 0.0, -180.0, Arc2D.PIE), Color.RED, Color.WHITE, thin);
    add(mouth);
  }
}
