package flower;

import java.awt.geom.*;

import visual.statik.described.*;
import visual.dynamic.described.*;

/**
 * A FLower that leans over and then springs back.
 * 
 * @author Prof. David Bernstein, James Madison University
 * @version 1.0
 */
public class LaunchingFlower extends DescribedSprite
  {
  
  /**
   * Explicit Value Constructor.
   * 
   * @param xInitial The initial x-coordinate on the stage
   * @param yInitial The initial y-coordinate on the stage
   */
   public LaunchingFlower(double xInitial, double yInitial)
    {
      super();
      UprightFlower upright = new UprightFlower(false);
      LeaningFlower leaning = new LeaningFlower();
      UprightFlower smiling = new UprightFlower(true);
      
      int time = 4000;
      addKeyTime(time +    0, xInitial, yInitial, upright);
      addKeyTime(time + 7500, xInitial, yInitial, null);
      addKeyTime(time + 7900, xInitial, yInitial, leaning);
      addKeyTime(time +15000, xInitial, yInitial, null);
      addKeyTime(time +15100, xInitial, yInitial, upright);
      addKeyTime(time +15200, xInitial, yInitial, null);
      addKeyTime(time +16700, xInitial, yInitial, null);
      addKeyTime(time +17700, xInitial, yInitial, smiling);
    }
    
   /**
    * A convenience method that adds a key time (with a rotation of 0.0 and a scaling of 1.0)
    * to this DescribedSprite.
    * 
    * @param time The time
    * @param x The x-coordinate
    * @param y The y-coordinate
    * @param c The Content to use (or null)
    */  
   private void addKeyTime(int time, double x, double y, AggregateContent c)
    {
        addKeyTime(time, new Point2D.Double(x, y), Double.valueOf(0.0), Double.valueOf(1.0), c);
    }
}
